@@ -13,7 +13,7 @@ BEGIN {
     __PACKAGE__->mk_accessors(qw/_config realm/);
 }
 
-our $VERSION = "0.12";
+our $VERSION = "1.000";
 
 sub new {
     my ($class, $config, $app, $realm) = @_;
@@ -372,8 +372,8 @@ __END__
 
 =head1 NAME
 
-Catalyst::Authentication::Credential::HTTP - Superseded / deprecated module 
-providing HTTP Basic and Digest authentication for Catalyst applications.
+Catalyst::Authentication::Credential::HTTP - HTTP Basic and Digest authentication
+for Catalyst.
 
 =head1 SYNOPSIS
 
@@ -410,20 +410,6 @@ providing HTTP Basic and Digest authentication for Catalyst applications.
     # with ACL plugin
     __PACKAGE__->deny_access_unless("/path", sub { $_[0]->authenticate });
 
-=head1 DEPRECATION NOTICE
-
-Please note that this module is B<DEPRECATED>, it has been Superseded by
-L<Catalyst::Authentication::Credential::HTTP>, please use that module in
-any new projects.
-
-Porting existing projects to use the new module should also be easy, and
-if there are any facilities in this module which you cannot see how to achieve
-in the new module then I<please contact the maintainer> as this is a bug and 
-I<will be fixed>.
-
-Let me say that again: B<THIS MODULE IS NOT SUPPORTED>, use 
-L<Catalyst::Authentication::Credential::HTTP> instead.
-
 =head1 DESCRIPTION
 
 This module lets you use HTTP authentication with
